@@ -25,17 +25,16 @@
 #include <QMap>
 #include <QWizard>
 
-#include <kio_version.h>
-#include "ui_creationsourceui.h"
 #include "ui_creationsourcedetailsui.h"
+#include "ui_creationsourceui.h"
 #include "ui_kdedocsourceui.h"
+#include <kio_version.h>
 
 class CompletionWizardWidget;
 class KComboBox;
 class MergeWidget;
 class QScrollArea;
 class QSpinBox;
-class QTextCodec;
 
 class CreationSourceWidget : public QWizardPage, public Ui::CreationSourceUI
 {
@@ -81,11 +80,7 @@ public:
         setObjectName(QLatin1String(name));
         languageButton->showLanguageCodes(true);
         languageButton->loadAllLanguages();
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
         ooDictURL->setNameFilter(QStringLiteral("*.dic"));
-#else
-        ooDictURL->setFilter(QStringLiteral("*.dic"));
-#endif
     }
     int nextId() const override
     {
@@ -102,10 +97,7 @@ class DictionaryCreationWizard : public QWizard
 {
     Q_OBJECT
 public:
-    DictionaryCreationWizard(QWidget *parent,
-                             const QStringList &dictionaryNames,
-                             const QStringList &dictionaryFiles,
-                             const QStringList &dictionaryLanguages);
+    DictionaryCreationWizard(QWidget *parent, const QStringList &dictionaryNames, const QStringList &dictionaryFiles, const QStringList &dictionaryLanguages);
     ~DictionaryCreationWizard() override;
 
     QString createDictionary();
@@ -117,11 +109,10 @@ public:
         FilePage,
         DirPage,
         KDEDocPage,
-        MergePage
+        MergePage,
     };
 
 private:
-    void buildCodecList();
     void buildCodecCombo(KComboBox *combo);
 
     CreationSourceWidget *creationSource;
@@ -129,8 +120,6 @@ private:
     CreationSourceDetailsWidget *dirWidget;
     KDEDocSourceWidget *kdeDocWidget;
     MergeWidget *mergeWidget;
-
-    QList<QTextCodec*> *codecList;
 };
 
 /**
@@ -142,19 +131,16 @@ class MergeWidget : public QWizardPage
 {
     Q_OBJECT
 public:
-    MergeWidget(QWidget *parent,
-                const QStringList &dictionaryNames,
-                const QStringList &dictionaryFiles,
-                const QStringList &dictionaryLanguages);
+    MergeWidget(QWidget *parent, const QStringList &dictionaryNames, const QStringList &dictionaryFiles, const QStringList &dictionaryLanguages);
     ~MergeWidget() override;
 
-    QMap <QString, int> mergeParameters();
+    QMap<QString, int> mergeParameters();
     QString language();
 
 private:
     QScrollArea *scrollArea;
-    QHash<QString, QCheckBox*> dictionaries;
-    QHash<QString, QSpinBox*> weights;
+    QHash<QString, QCheckBox *> dictionaries;
+    QHash<QString, QSpinBox *> weights;
     QMap<QString, QString> languages;
 };
 
@@ -167,6 +153,7 @@ class CompletionWizardWidget : public QWizardPage, public Ui::KDEDocSourceUI
 {
     Q_OBJECT
     friend class ConfigWizard;
+
 public:
     CompletionWizardWidget(QWidget *parent, const char *name);
     ~CompletionWizardWidget() override;
